/*
 * Copyright 2016 by Kappich Systemberatung Aachen
 * 
 * This file is part of de.bsvrz.dua.tests.
 * 
 * de.bsvrz.dua.tests is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * de.bsvrz.dua.tests is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.dua.tests.  If not, see <http://www.gnu.org/licenses/>.

 * Contact Information:
 * Kappich Systemberatung
 * Martin-Luther-Straße 14
 * 52062 Aachen, Germany
 * phone: +49 241 4090 436 
 * mail: <info@kappich.de>
 */

package de.bsvrz.dua.tests;

import de.bsvrz.dav.daf.main.DataDescription;
import de.bsvrz.dav.daf.main.config.SystemObject;

import java.util.Arrays;

/**
 * TBD Dokumentation
 *
 * @author Kappich Systemberatung
 */
public class DuADataIdentification {
	private final SystemObject[] _objects;
	private final ComplexDataDescription _dataDescription;

	public DuADataIdentification(final SystemObject object, final DataDescription dataDescription) {
		this(new SystemObject[]{object}, dataDescription);
	}
	
	public DuADataIdentification(final SystemObject[] objects, final DataDescription dataDescription) {
		this(objects, new ComplexDataDescription(dataDescription));
	}
	
	public DuADataIdentification(final SystemObject object, final ComplexDataDescription dataDescription) {
		this(new SystemObject[]{object}, dataDescription);
	}	
	
	public DuADataIdentification(final SystemObject[] objects, final ComplexDataDescription dataDescription) {
		_objects = objects;
		_dataDescription = dataDescription;
	}

	public SystemObject[] getObjects() {
		return _objects;
	}

	public ComplexDataDescription getDataDescription() {
		return _dataDescription;
	}

	@Override
	public boolean equals(final Object o) {
		if(this == o) return true;
		if(!(o instanceof DuADataIdentification)) return false;

		final DuADataIdentification that = (DuADataIdentification) o;

		// Probably incorrect - comparing Object[] arrays with Arrays.equals
		if(!Arrays.equals(_objects, that._objects)) return false;
		return _dataDescription != null ? _dataDescription.equals(that._dataDescription) : that._dataDescription == null;

	}

	@Override
	public int hashCode() {
		int result = Arrays.hashCode(_objects);
		result = 31 * result + (_dataDescription != null ? _dataDescription.hashCode() : 0);
		return result;
	}
}
